@@ -20,11 +20,14 @@ class CursorPagination(DefaultCursorPagination):
             self.aggregates = view.get_aggregates(queryset, paginated_queryset)
 
         if hasattr(view, "get_messages"):
-            self.messages = view.get_messages(
+            messages = view.get_messages(
                 request=request,
                 queryset=queryset,
                 paginated_queryset=paginated_queryset,
+                initial=not bool(self.cursor)
             )
+            if messages:
+                self.messages = [dict(message) for message in messages]
 
         return paginated_queryset
 
